==> ejc-purchasingmanagement-impl-3.0.0-20220424.052451-26-sources.jar: com/ejianc/business/purchasingmanagement/controller/MaterialacceptanceController.java <==
package com.ejianc.business.purchasingmanagement.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.purchasingmanagement.bean.MaterialpaymentEntity;
import com.ejianc.business.purchasingmanagement.vo.MaterialpaymentdetailVO;
import com.ejianc.business.purchasingmanagement.vo.SupplierinvoicedetialVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.purchasingmanagement.bean.MaterialacceptanceEntity;
import com.ejianc.business.purchasingmanagement.service.IMaterialacceptanceService;
import com.ejianc.business.purchasingmanagement.vo.MaterialacceptanceVO;

/**
 * 采购材料验收
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("materialacceptance")
public class MaterialacceptanceController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IMaterialacceptanceService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<MaterialacceptanceVO> saveOrUpdate(@RequestBody MaterialacceptanceVO saveOrUpdateVO) {
        MaterialacceptanceEntity entity = BeanMapper.map(saveOrUpdateVO, MaterialacceptanceEntity.class);
        if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
               // entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        entity.setConfirmStatus(1);
        service.saveOrUpdate(entity, false);
        MaterialacceptanceVO vo = BeanMapper.map(entity, MaterialacceptanceVO.class);
        return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<MaterialacceptanceVO> queryDetail(Long id) {
        MaterialacceptanceEntity entity = service.selectById(id);
        MaterialacceptanceVO vo = BeanMapper.map(entity, MaterialacceptanceVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<MaterialacceptanceVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (MaterialacceptanceVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(MaterialacceptanceVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<MaterialacceptanceVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<MaterialacceptanceEntity> page = service.queryPage(param,false);
        IPage<MaterialacceptanceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), MaterialacceptanceVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<MaterialacceptanceEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Materialacceptance-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refMaterialacceptanceData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<MaterialacceptanceVO>> refMaterialacceptanceData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                                 String condition,
                                                                                 String searchObject,
                                                                                 String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<MaterialacceptanceEntity> page = service.queryPage(param,false);
        IPage<MaterialacceptanceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), MaterialacceptanceVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
    }
    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     *
     */
    @RequestMapping(value = "/materialacceptancelist", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<List<MaterialpaymentdetailVO>> receivableslist(@RequestBody QueryParam param) {
        QueryWrapper<MaterialacceptanceEntity> queryWrapper = new QueryWrapper<>();
        if(param.getParams().get("supplierinfo_id").getValue() != null){
            //param.getParams().remove("customer_name");
            queryWrapper.eq("supplierinfo_id",param.getParams().get("supplierinfo_id").getValue());
        }
        if(param.getParams().get("org_Id").getValue() != null){
            //param.getParams().remove("customer_name");
            queryWrapper.eq("org_Id",param.getParams().get("org_Id").getValue());
        }
      //  queryWrapper.ne("uncollected_moeny",new BigDecimal(0.00000000));
        List<MaterialacceptanceEntity> list = service.list(queryWrapper);
        List<MaterialpaymentdetailVO> materialpaymentdetailList = new ArrayList<>();
        for ( MaterialacceptanceEntity temp : list ) {
            MaterialpaymentdetailVO vo = new MaterialpaymentdetailVO();
            vo.setId(temp.getId());
            vo.setMaterialacceptanceId(temp.getId());//材料验收主键
            vo.setMaterialId(temp.getMaterialId());//原材料id
            vo.setMaterialName(temp.getMaterialName());//原材料
            vo.setAcceptanceDate(temp.getAcceptanceDate());//验收时间
            vo.setQuantity(temp.getAcceptanceQuantity());//验收数量
            vo.setAmount(temp.getAmount());//金额
            vo.setUncollectedMoney(temp.getAmount().subtract(new BigDecimal(0.0)));
            vo.setReceivedMoney(new BigDecimal(0.0));
            vo.setOtherReceivedMoney(new BigDecimal(0.0));
            vo.setBillCode(temp.getBillCode());
            vo.setRowState("add");
            materialpaymentdetailList.add(vo);
        }



        return CommonResponse.success("查询列表数据成功！",materialpaymentdetailList);

    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     *
     */
    @RequestMapping(value = "/supplierinvoicedetialist", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<List<SupplierinvoicedetialVO>> supplierinvoicedetialist(@RequestBody QueryParam param) {
        QueryWrapper<MaterialacceptanceEntity> queryWrapper = new QueryWrapper<>();
        if(param.getParams().get("supplierinfo_id").getValue() != null){
            //param.getParams().remove("customer_name");
            queryWrapper.eq("supplierinfo_id",param.getParams().get("supplierinfo_id").getValue());
        }
        if(param.getParams().get("org_Id").getValue() != null){
            //param.getParams().remove("customer_name");
            queryWrapper.eq("org_Id",param.getParams().get("org_Id").getValue());
        }
        //  queryWrapper.ne("uncollected_moeny",new BigDecimal(0.00000000));
        List<MaterialacceptanceEntity> list = service.list(queryWrapper);
        List<SupplierinvoicedetialVO> supplierinvoicedetialVOS = new ArrayList<>();
        for ( MaterialacceptanceEntity temp : list ) {
            SupplierinvoicedetialVO vo = new SupplierinvoicedetialVO();
            vo.setId(temp.getId());
            vo.setMaterialacceptanceId(temp.getId());//付款单主键
            vo.setUncollectedMoney(temp.getAmount());
            vo.setReceivedMoney(new BigDecimal(0.0));
            vo.setOtherReceivedMoney(new BigDecimal(0.0));
            vo.setBillCode(temp.getBillCode());
            vo.setReceivablesDate(temp.getAcceptanceDate());
            vo.setInvoiceMoney(temp.getAmount());
            vo.setRowState("add");
            supplierinvoicedetialVOS.add(vo);
        }
        return CommonResponse.success("查询列表数据成功！",supplierinvoicedetialVOS);

    }




}

==> ejc-purchasingmanagement-impl-3.0.0-20220511.150614-65-sources.jar: com/ejianc/business/purchasingmanagement/controller/MaterialacceptanceController.java <==
package com.ejianc.business.purchasingmanagement.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.purchasingmanagement.bean.MaterialpaymentEntity;
import com.ejianc.business.purchasingmanagement.vo.MaterialpaymentdetailVO;
import com.ejianc.business.purchasingmanagement.vo.SupplierinvoicedetialVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.purchasingmanagement.bean.MaterialacceptanceEntity;
import com.ejianc.business.purchasingmanagement.service.IMaterialacceptanceService;
import com.ejianc.business.purchasingmanagement.vo.MaterialacceptanceVO;

/**
 * 采购材料验收
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("materialacceptance")
public class MaterialacceptanceController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IMaterialacceptanceService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<MaterialacceptanceVO> saveOrUpdate(@RequestBody MaterialacceptanceVO saveOrUpdateVO) {
        MaterialacceptanceEntity entity = BeanMapper.map(saveOrUpdateVO, MaterialacceptanceEntity.class);
        if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
               // entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        service.saveOrUpdate(entity, false);
        MaterialacceptanceVO vo = BeanMapper.map(entity, MaterialacceptanceVO.class);
        return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<MaterialacceptanceVO> queryDetail(Long id) {
        MaterialacceptanceEntity entity = service.selectById(id);
        MaterialacceptanceVO vo = BeanMapper.map(entity, MaterialacceptanceVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<MaterialacceptanceVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (MaterialacceptanceVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(MaterialacceptanceVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<MaterialacceptanceVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<MaterialacceptanceEntity> page = service.queryPage(param,false);
        IPage<MaterialacceptanceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), MaterialacceptanceVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<MaterialacceptanceEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Materialacceptance-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refMaterialacceptanceData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<MaterialacceptanceVO>> refMaterialacceptanceData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                                 String condition,
                                                                                 String searchObject,
                                                                                 String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<MaterialacceptanceEntity> page = service.queryPage(param,false);
        IPage<MaterialacceptanceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), MaterialacceptanceVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
    }
    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     *
     */
    @RequestMapping(value = "/materialacceptancelist", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<List<MaterialpaymentdetailVO>> receivableslist(@RequestBody QueryParam param) {
        QueryWrapper<MaterialacceptanceEntity> queryWrapper = new QueryWrapper<>();
        if(param.getParams().get("supplierinfo_id").getValue() != null){
            //param.getParams().remove("customer_name");
            queryWrapper.eq("supplierinfo_id",param.getParams().get("supplierinfo_id").getValue());
        }
        if(param.getParams().get("org_Id").getValue() != null){
            //param.getParams().remove("customer_name");
            queryWrapper.eq("org_Id",param.getParams().get("org_Id").getValue());

        }
        queryWrapper.eq("confirm_status",1);
        queryWrapper.ne("amount_not_paid",new BigDecimal(0.00000000));
        List<MaterialacceptanceEntity> list = service.list(queryWrapper);
        List<MaterialpaymentdetailVO> materialpaymentdetailList = new ArrayList<>();
        for ( MaterialacceptanceEntity temp : list ) {
            MaterialpaymentdetailVO vo = new MaterialpaymentdetailVO();
            vo.setId(temp.getId());
            vo.setMaterialacceptanceId(temp.getId());//材料验收主键6
            vo.setMaterialId(temp.getMaterialId());//原材料id
            vo.setMaterialName(temp.getMaterialName());//原材料
            vo.setAcceptanceDate(temp.getAcceptanceDate());//验收时间
            vo.setQuantity(temp.getAcceptanceQuantity());//验收数量
            vo.setAmount(temp.getTotalAmount());//金额
            vo.setReceivableMoney(temp.getTotalAmount());//应收金额
            //未付金额
            if(temp.getAmountNotPaid()!=null){
                vo.setUncollectedMoney(temp.getAmountNotPaid());
            }else{
                vo.setUncollectedMoney(temp.getTotalAmount());
            }


            vo.setReceivedMoney(new BigDecimal(0.0));
            //其他单已付金额
            if(temp.getAmountPaid()!=null){
                vo.setOtherReceivedMoney(temp.getAmountPaid());
            }else{
                vo.setOtherReceivedMoney(new BigDecimal(0.0));
            }
            vo.setBillCode(temp.getBillCode());
            vo.setRowState("add");
            materialpaymentdetailList.add(vo);
        }
        return CommonResponse.success("查询列表数据成功！",materialpaymentdetailList);

    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     *
     */
    @RequestMapping(value = "/supplierinvoicedetialist", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<List<SupplierinvoicedetialVO>> supplierinvoicedetialist(@RequestBody QueryParam param) {
        QueryWrapper<MaterialacceptanceEntity> queryWrapper = new QueryWrapper<>();
        if(param.getParams().get("supplierinfo_id").getValue() != null){
            //param.getParams().remove("customer_name");
            queryWrapper.eq("supplierinfo_id",param.getParams().get("supplierinfo_id").getValue());
        }
        if(param.getParams().get("org_Id").getValue() != null){
            //param.getParams().remove("customer_name");
            queryWrapper.eq("org_Id",param.getParams().get("org_Id").getValue());
        }
        queryWrapper.eq("confirm_status",1);
        queryWrapper.ne("invoice_not_received",new BigDecimal(0.00000000));
        List<MaterialacceptanceEntity> list = service.list(queryWrapper);
        List<SupplierinvoicedetialVO> supplierinvoicedetialVOS = new ArrayList<>();
        for ( MaterialacceptanceEntity temp : list ) {
            SupplierinvoicedetialVO vo = new SupplierinvoicedetialVO();
            vo.setId(temp.getId());
            vo.setMaterialacceptanceId(temp.getId());//付款单主键
            if(temp.getInvoiceNotReceived()!=null){
                vo.setUncollectedMoney(temp.getInvoiceNotReceived());
            }else{
                vo.setUncollectedMoney(temp.getTotalAmount());
            }
            vo.setReceivedMoney(new BigDecimal(0.0));
            if(temp.getInvoiceReceived()!=null){
                vo.setOtherReceivedMoney(temp.getInvoiceReceived());
            }else{
                vo.setOtherReceivedMoney(new BigDecimal(0.0));
            }


            vo.setBillCode(temp.getBillCode());
            vo.setReceivablesDate(temp.getAcceptanceDate());
            vo.setInvoiceMoney(temp.getTotalAmount());
            vo.setRowState("add");
            supplierinvoicedetialVOS.add(vo);
        }
        return CommonResponse.success("查询列表数据成功！",supplierinvoicedetialVOS);

    }




}
